@@ -270,7 +270,7 @@ void show_progress(const char* filename, unsigned int position)
     char* short_name = NULL;
     const char* name = filename;
 
-    if (!get_console_size(1, &width, &height))
+    if (!get_console_size(0, &width, &height))
     {
         unsigned int full_length = strlen(filename);
 
@@ -390,9 +390,9 @@ int get_gain(const char* filename, float* track_peak, float* track_gain,
     {
         if (!settings->quiet)
         {
-            fprintf(stderr, _("Analyzing files...\n\n"));
-            fprintf(stderr, _("   Gain   |  Peak  | Scale | New Peak | Track\n"));
-            fprintf(stderr, _("----------+--------+-------+----------+------\n"));
+            fprintf(stdout, _("Analyzing files...\n\n"));
+            fprintf(stdout, _("   Gain   |  Peak  | Scale | New Peak | Track\n"));
+            fprintf(stdout, _("----------+--------+-------+----------+------\n"));
         }
 
         settings->first_file = 0;
@@ -402,7 +402,8 @@ int get_gain(const char* filename, float* track_peak, float* track_gain,
     {
         file_length = ov_pcm_total(&vf, -1);
 
-        if ((file_length > 0) && (ov_pcm_tell(&vf) >= 0))
+        if (settings->show_progress && (file_length > 0) 
+	    && (ov_pcm_tell(&vf) >= 0))
         {
             show_progress(filename, 0);
         }
@@ -507,9 +508,12 @@ int get_gain(const char* filename, float* track_peak, float* track_gain,
                 if ((100 == percentage) || ((percentage != previous_percentage) 
                     && (difftime(curr_time, previous_time) >= 1)))
                 {
+		  if (settings->show_progress) 
+		  {
                     show_progress(filename, percentage);
-                    previous_percentage = percentage;
-                    previous_time = curr_time;
+		  }
+		  previous_percentage = percentage;
+		  previous_time = curr_time;
                 }
             }
         }
@@ -522,7 +526,7 @@ int get_gain(const char* filename, float* track_peak, float* track_gain,
 
     if (!settings->quiet)
     {
-        fprintf(stderr, _("%+6.2f dB | %6.0f | %5.2f | %8.0f | %s\n"),
+        fprintf(stdout, _("%+6.2f dB | %6.0f | %5.2f | %8.0f | %s\n"),
             *track_gain, peak, scale, new_peak, filename);
     }
 
